@@ -11,10 +11,10 @@ NAME = __name__.split('.')[-1] # package name (e.g. 'foo' or 'foo_bar')
                                # please use a all-lowercase valid python
                                # package name
 
-VERSION = '3.1.1' # version of the packaged files, please use the upstream
+VERSION = '3.3.7' # version of the packaged files, please use the upstream
                   # version number
-BUILD = '1' # our package build number, so we can release new builds
-             # with fixes for xstatic stuff.
+BUILD = '0' # our package build number, so we can release new builds
+            # with fixes for xstatic stuff.
 PACKAGE_VERSION = VERSION + '.' + BUILD # version used for PyPi
 
 DESCRIPTION = "%s %s (XStatic packaging standard)" % (DISPLAY_NAME, VERSION)
@@ -28,10 +28,10 @@ MAINTAINER = 'Radomir Dopieralski'
 MAINTAINER_EMAIL = 'openstack@sheep.art.pl'
 
 # this refers to the project homepage of the stuff we packaged:
-HOMEPAGE = 'http://getbootstrap.org/'
+HOMEPAGE = 'http://getbootstrap.com/'
 
 # this refers to all files:
-LICENSE = '(same as %s)' % DISPLAY_NAME
+LICENSE = 'MIT'
 
 from os.path import join, dirname
 BASE_DIR = join(dirname(__file__), 'data')
